@@ -31,6 +31,29 @@ class TestGetBlobHttpsUrl < Minitest::Test
     end
   end
 
+  def test_get_blob_https_url_with_content_disposition
+    mock_generate_uri = Minitest::Mock.new
+    mock_generate_service_token = Minitest::Mock.new
+    url_params = { content_disposition: 'attachment' }
+
+    2.times do
+      mock_generate_uri.expect(:call, @url, ['test_container/test_blob', {}, { encode: true }])
+      mock_generate_service_token.expect(:call, @token) do |_relative_path, params|
+        params[:service] == 'b' &&
+          params[:resource] == 'b' &&
+          params[:permissions] == 'r' &&
+          params[:content_disposition] == url_params[:content_disposition]
+      end
+    end
+
+    @blob_client.stub :generate_uri, mock_generate_uri do
+      @signature_client.stub :generate_service_sas_token, mock_generate_service_token do
+        assert_equal "#{@url}?#{@token}", @service.get_blob_https_url('test_container', 'test_blob', Time.now.utc + 3600, url_params)
+        assert_equal "#{@url}?#{@token}", @service.get_object_url('test_container', 'test_blob', Time.now.utc + 3600, url_params)
+      end
+    end
+  end
+
   def test_get_url_remove_trailing_periods_from_path_segments
     mock_generate_uri = Minitest::Mock.new
     mock_generate_service_token = Minitest::Mock.new
